pub struct StrategyRecord {
pub strategy_id: u16,
pub asset_id: u16,
pub balance: u64,
pub net_earnings: i64,
}Expand description
Strategy record within vault
Fields
strategy_id: u16asset_id: u16balance: u64net_earnings: i64Trait Implementations
Sourceimpl BorshDeserialize for StrategyRecord
impl BorshDeserialize for StrategyRecord
fn deserialize_reader<__R: Read>(reader: &mut __R) -> Result<Self, Error>
Sourcefn deserialize(buf: &mut &[u8]) -> Result<Self, Error>
fn deserialize(buf: &mut &[u8]) -> Result<Self, Error>
Deserializes this instance from a given slice of bytes.
Updates the buffer to point at the remaining bytes.
Sourcefn try_from_slice(v: &[u8]) -> Result<Self, Error>
fn try_from_slice(v: &[u8]) -> Result<Self, Error>
Deserialize this instance from a slice of bytes.
fn try_from_reader<R>(reader: &mut R) -> Result<Self, Error>where
R: Read,
Sourceimpl BorshSerialize for StrategyRecord
impl BorshSerialize for StrategyRecord
Sourceimpl Clone for StrategyRecord
impl Clone for StrategyRecord
Sourcefn clone(&self) -> StrategyRecord
fn clone(&self) -> StrategyRecord
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreAuto Trait Implementations
impl Freeze for StrategyRecord
impl RefUnwindSafe for StrategyRecord
impl Send for StrategyRecord
impl Sync for StrategyRecord
impl Unpin for StrategyRecord
impl UnwindSafe for StrategyRecord